@@ -1,9 +1,9 @@
 package BorderStyle::ASCII::SingleLineHorizontalOnly;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-19'; # DATE
+our $DATE = '2021-05-12'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 use parent 'BorderStyleBase';
@@ -36,7 +36,7 @@ BorderStyle::ASCII::SingleLineHorizontalOnly - Single line border with ASCII cha
 
 =head1 VERSION
 
-This document describes version 0.006 of BorderStyle::ASCII::SingleLineHorizontalOnly (from Perl distribution BorderStyles-Standard), released on 2021-02-19.
+This document describes version 0.007 of BorderStyle::ASCII::SingleLineHorizontalOnly (from Perl distribution BorderStyles-Standard), released on 2021-05-12.
 
 =head1 SYNOPSIS
 
@@ -67,9 +67,9 @@ Sample output:
    row3A        row3B         row3C        
  ------------------------------------------
 
-To use with L<Text::Table::Span>:
+To use with L<Text::Table::More>:
 
- use Text::Table::Span qw/generate_table/;
+ use Text::Table::More qw/generate_table/;
  my $rows =
    [
      ["ColumName1", "ColumnNameB", "ColumnNameC"],
@@ -128,7 +128,7 @@ Source repository is at L<https://github.com/perlancar/perl-BorderStyles-Standar
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-BorderStyles-Standard/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=BorderStyles-Standard>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
